CrystalFmt class

Properties

crystalHourStyle CrystalHourStyle?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format({DateTime? dateTime, AbstractCrystalLocale locale = const CrystalFrenchLocale(), String timezone = "Europe/Paris"}) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseToDateTime(String date) DateTime
parseToTimeOfDay(String date) TimeOfDay
prefix(int dateOrMonth) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

ofPattern({String? pattern, CrystalFormatStyle? formatStyle, CrystalHourStyle? crystalHourStyle}) → dynamic